@@ -7,7 +7,7 @@ from __future__ import print_function
     This uses the Python type P4API.P4Adapter, which is a wrapper for the
     Perforce ClientApi object.
     
-    $Id: //depot/r17.1/p4-python/P4.py#1 $
+    $Id: //depot/r17.2/p4-python/P4.py#1 $
     
     #*******************************************************************************
     # Copyright (c) 2007-2010, Perforce Software, Inc.  All rights reserved.
@@ -606,7 +606,10 @@ class P4(P4API.P4Adapter):
         except P4Exception as e:
             if self.logger:
                 self.log_messages()
+            for (k,v) in list(context.items()):
+                setattr( self, k, v)
             raise e
+        
         if self.logger:
             self.log_messages()
         
@@ -805,22 +808,28 @@ class P4(P4API.P4Adapter):
     def while_tagged( self, t ):
         old = self.tagged
         self.tagged = t
-        yield
-        self.tagged = old
+        try:
+            yield
+        finally:
+            self.tagged = old
     
     @contextmanager
     def at_exception_level( self, e ):
         old = self.exception_level
         self.exception_level = e
-        yield
-        self.exception_level = old
+        try:
+            yield
+        finally:
+            self.exception_level = old
     
     @contextmanager
     def using_handler( self, c ):
         old = self.handler
         self.handler = c
-        yield
-        self.handler = old
+        try:
+            yield
+        finally:
+            self.handler = old
     
     @contextmanager
     def saved_context( self , **kargs):
@@ -833,17 +842,18 @@ class P4(P4API.P4Adapter):
         for (k,v) in list(kargs.items()):
             setattr( self, k, v)
         
-        yield
-        
-        # now restore the context again. Ignore AttributeError exception
-        # Exception is expected because some attributes only have getters, no setters
-        
-        for (k,v) in list(saved_context.items()):
-            if k not in ("port", "track"):
-                try:
-                    setattr( self, k, v )
-                except AttributeError:
-                    pass # expected for server_level and p4config_file
+        try:
+            yield
+        finally:
+            # now restore the context again. Ignore AttributeError exception
+            # Exception is expected because some attributes only have getters, no setters
+            
+            for (k,v) in list(saved_context.items()):
+                if k not in ("port", "track"):
+                    try:
+                        setattr( self, k, v )
+                    except AttributeError:
+                        pass # expected for server_level and p4config_file
 
     @contextmanager
     def temp_client( self, prefix, template ):
