@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r17.1/p4-python/P4API.cpp#1 $
+ * $Id: //depot/r17.2/p4-python/P4API.cpp#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -1221,6 +1221,17 @@ PyTypeObject P4MapType = {
 // ==== P4Message ====
 // ===================
 
+static
+PyObject *P4Message_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
+{
+    P4Message *self = (P4Message *) type->tp_alloc(type, 0);
+    if (self != NULL) {
+        self->msg = NULL;
+    }
+
+    return (PyObject *) self;
+}
+
 static void
 P4Message_dealloc(P4Message *self)
 {
@@ -1292,7 +1303,7 @@ PyTypeObject P4MessageType =
 	    (getattrofunc) P4Message_getattro,          /* tp_getattro*/
 	    0,                                          /* tp_setattro*/
 	    0,                                          /* tp_as_buffer*/
-	    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,   /* tp_flags*/
+	    Py_TPFLAGS_DEFAULT,                         /* tp_flags*/
 	    "P4Message - errors and warnings",          /* tp_doc */
 	    0,                                          /* tp_traverse */
 	    0,                                          /* tp_clear */
@@ -1310,7 +1321,7 @@ PyTypeObject P4MessageType =
 	    0,                                          /* tp_dictoffset */
 	    (initproc) P4Message_init,                  /* tp_init */
 	    0,                                          /* tp_alloc */
-	    0,                                          /* tp_new */
+	    P4Message_new,                              /* tp_new */
 };
 
 
@@ -1380,6 +1391,14 @@ initP4API(void)
 {
     if (PyType_Ready(&P4AdapterType) < 0) 
 	INITERROR;
+    if (PyType_Ready(&P4MapType) < 0)
+        INITERROR;
+    if (PyType_Ready(&P4MergeDataType) < 0)
+        INITERROR;
+    if (PyType_Ready(&P4ActionMergeDataType) < 0)
+        INITERROR;
+    if (PyType_Ready(&P4MessageType) < 0)
+        INITERROR;
 
 #if PY_MAJOR_VERSION >= 3
     PyObject * module = PyModule_Create(&P4API_moduledef);
