@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r17.1/p4-python/PythonClientAPI.cpp#1 $
+$Id: //depot/r17.2/p4-python/PythonClientAPI.cpp#1 $
 *******************************************************************************/
  
 #include <Python.h>
@@ -129,6 +129,21 @@ PythonClientAPI::~PythonClientAPI()
     delete enviro;
 }
 
+StrBuf PythonClientAPI::SetProgString(StrBuf& progStr)
+{
+    StrBuf result = progStr;
+
+    result << " [PY";
+    result << PY_VERSION;
+    result << "/P4PY";
+    result << ID_REL;
+    result << "/API";
+    result << ID_API;
+    result << "]";
+
+    return result;
+}
+
 PyObject *  PythonClientAPI::DisableTmpCleanup()
 {
     ui.DisableTmpCleanup();
@@ -1198,16 +1213,12 @@ void PythonClientAPI::Except( const char *func, const char *msg, const char *cmd
 
 void PythonClientAPI::RunCmd(const char *cmd, ClientUser *ui, int argc, char * const *argv)
 {
-// #if P4APIVER_ID >= 513026
-    // ClientApi::SetProg() was introduced in 2004.2
-    client.SetProg( &prog );
-// #endif
+    StrBuf theProgStr = SetProgString(prog);
+
+    client.SetProg( &theProgStr );
 
-// #if P4APIVER_ID >= 513282
-    // ClientApi::SetVersion() was introduced in 2005.2
     if( version.Length() )
 	client.SetVersion( &version );
-// #endif
 
     if( IsTag() )
         client.SetVar( "tag" );
