@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r17.1/p4-python/PythonClientUser.cpp#1 $
+$Id: //depot/r17.2/p4-python/PythonClientUser.cpp#1 $
 
 *******************************************************************************/
  
@@ -594,21 +594,27 @@ int PythonClientUser::Resolve( ClientMerge *m, Error *e )
 	Py_DECREF( result );
     }
 
-    StrBuf reply = GetPythonString( result );
+    if (IsString(result)) {
+        StrBuf reply = GetPythonString( result );
 
-    if( reply == "ay" ) 		return CMS_YOURS;
-    else if( reply == "at" )	return CMS_THEIRS;
-    else if( reply == "am" )	return CMS_MERGED;
-    else if( reply == "ae" )	return CMS_EDIT;
-    else if( reply == "s" )		return CMS_SKIP;
-    else if( reply == "q" ) 	return CMS_QUIT;
+        if( reply == "ay" ) 		return CMS_YOURS;
+        else if( reply == "at" )	return CMS_THEIRS;
+        else if( reply == "am" )	return CMS_MERGED;
+        else if( reply == "ae" )	return CMS_EDIT;
+        else if( reply == "s" )		return CMS_SKIP;
+        else if( reply == "q" ) 	return CMS_QUIT;
+        else {
+            StrBuf warning("[P4::Resolve] Illegal response : '");
+            warning << reply;
+            warning << "', skipping resolve";
+
+            PyErr_WarnEx( PyExc_UserWarning, warning.Text(), 1);
+            return CMS_QUIT;
+        }
+    }
     else {
-	StrBuf warning("[P4::Resolve] Illegal response : '");
-	warning << reply;
-	warning << "', skipping resolve";
-
-	PyErr_WarnEx( PyExc_UserWarning, warning.Text(), 1);
-	return CMS_QUIT;
+        PyErr_WarnEx( PyExc_UserWarning, "[P4::Resolve] Illegal response : Expected String", 1);
+        return CMS_QUIT;
     }
 }
 
