@@ -23,7 +23,7 @@
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
- $Id: //depot/r17.1/p4-python/SpecMgr.cpp#1 $
+ $Id: //depot/r17.2/p4-python/SpecMgr.cpp#1 $
  *******************************************************************************/
 
 /*******************************************************************************
@@ -114,6 +114,7 @@ struct specdata {
 	"Backup;code:319;type:select;len:10;val:enable/disable;;"
 	"View;code:311;type:wlist;words:2;len:64;;"
 	"ChangeView;code:317;type:llist;len:64;;"
+  "RepoView;code:320;type:llist;len:64;;"
     },
     {
 	"depot",
@@ -233,7 +234,7 @@ struct specdata {
 	"ArchiveLimits;code:862;type:wlist;words:2;len:64;;"
     },
     {
-    "repo",
+  "repo",
 	"Repo;code:1001;rq;ro;len:128;;"
 	"Owner;code:1002;len:32;;"
 	"Created;code:1003;type:date;ro;fmt:L;len:20;;"
@@ -242,7 +243,8 @@ struct specdata {
 	"Description;code:1006;type:text;len:128;;"
 	"DefaultBranch;code:1007;len:32;;"
 	"MirroredFrom;code:1008;len:32;;"
-	},
+	"Options;code:1009;type:select;len:10;val:lfs/nolfs;;"
+  	},
     {
 	"server",
 	"ServerID;code:751;rq;ro;len:32;;"
