@@ -43,9 +43,11 @@ class TestP4Python(unittest.TestCase):
 
     def enableUnicode(self):
         cmd = [self.p4d, "-r", self.server_root, "-L", "log", "-vserver=3", "-xi"]
-        f = Popen(cmd, stdout=PIPE).stdout
+        p = Popen(cmd, stdout=PIPE)
+        f = p.stdout
         for s in f.readlines():
-          pass
+            pass
+        p.wait()
         f.close()
 
     def tearDown(self):
@@ -606,50 +608,49 @@ class TestP4(TestP4Python):
         self.assertEqual(p4.port, "9999")
         self.assertEqual(p4.client, "myclient")
 
-    if False:
-        def testUnicode( self ):
-            self.enableUnicode()
+    def testUnicode( self ):
+        self.enableUnicode()
 
-            testDir = 'test_files'
-            testAbsoluteDir = os.path.join(self.client_root, testDir)
-            os.mkdir(testAbsoluteDir)
+        testDir = 'test_files'
+        testAbsoluteDir = os.path.join(self.client_root, testDir)
+        os.mkdir(testAbsoluteDir)
 
-            self.p4.charset = 'iso8859-1'
-            self.p4.connect()
-            self._setClient()
+        self.p4.charset = 'iso8859-1'
+        self.p4.connect()
+        self._setClient()
 
-            # create a bunch of files
-            tf = os.path.join(testDir, "unicode.txt")
-            fname = os.path.join(self.client_root, tf)
+        # create a bunch of files
+        tf = os.path.join(testDir, "unicode.txt")
+        fname = os.path.join(self.client_root, tf)
 
-            if sys.version_info < (3,0):
-                with open(fname, "w") as f:
-                    f.write("This file cost \xa31")
-            else:
-                with open(fname, "wb") as f:
-                    f.write("This file cost \xa31".encode('iso8859-1'))
+        if sys.version_info < (3,0):
+            with open(fname, "w") as f:
+                f.write("This file cost \xa31")
+        else:
+            with open(fname, "wb") as f:
+                f.write("This file cost \xa31".encode('iso8859-1'))
 
-            self.p4.run_add('-t', 'unicode', tf)
+        self.p4.run_add('-t', 'unicode', tf)
 
-            self.p4.run_submit("-d", "Unicode file")
+        self.p4.run_submit("-d", "Unicode file")
 
-            self.p4.run_sync('...#0')
-            self.p4.charset = 'utf8'
+        self.p4.run_sync('...#0')
+        self.p4.charset = 'utf8'
 
-            self.p4.run_sync()
-            if sys.version_info < (3,0):
-                with open(fname, 'r') as f:
-                    buf = f.read()
-                    self.assertTrue(buf == "This file cost \xc2\xa31", "File not found, UNICODE support broken?")
-            else:
-                with open(fname, 'rb') as f:
-                    buf = f.read()
-                    self.assertTrue(buf == "This file cost \xa31".encode('utf-8'), "File not found, UNICODE support broken?")
+        self.p4.run_sync()
+        if sys.version_info < (3,0):
+            with open(fname, 'r') as f:
+                buf = f.read()
+                self.assertTrue(buf == "This file cost \xc2\xa31", "File not found, UNICODE support broken?")
+        else:
+            with open(fname, 'rb') as f:
+                buf = f.read()
+                self.assertTrue(buf == "This file cost \xa31".encode('utf-8'), "File not found, UNICODE support broken?")
 
-                ch = self.p4.run_changes(b'-m1')
-                self.assertEqual(len(ch), 1, "Byte strings broken")
+            ch = self.p4.run_changes(b'-m1')
+            self.assertEqual(len(ch), 1, "Byte strings broken")
 
-            self.p4.disconnect()
+        self.p4.disconnect()
 
     def testTrack( self ):
         success = self.p4.track = 1
@@ -1032,19 +1033,19 @@ class TestP4(TestP4Python):
     def testUntaggedSpecs( self ):
         self.p4.connect()
 
-        client = self.p4.fetch_client("testclient")
-        client._description = "Client for testing specs"
-        self.p4.save_client(client)
-        client= self.p4.fetch_client("testclient")
+        label = self.p4.fetch_label("label")
+        label._description = "Client for testing specs"
+        self.p4.save_label(label)
+        label = self.p4.fetch_label("label")
 
-        untagged = self.p4.fetch_client("testclient", tagged=False)
-        untagged_direct = self.p4.run_client("-o", "testclient", tagged=False)[0]
+        untagged = self.p4.fetch_label("label", tagged=False)
+        untagged_direct = self.p4.run_label("-o", "label", tagged=False)[0]
 
         self.assertEqual(untagged, untagged_direct, "fetch and direct do not match")
 
-        parsed = self.p4.parse_client(untagged)
+        parsed = self.p4.parse_label(untagged)
 
-        self.assertEqual(parsed, client, "parsed and fetched do not match")
+        self.assertEqual(parsed, label, "parsed and fetched do not match")
 
     def testEnviro( self ):
         self.p4.connect()
@@ -1249,6 +1250,48 @@ class TestP4(TestP4Python):
             else:
                 print("\n*** Please upgrade to at least 2016.1 Patch 2 (1398982) ***")
     
+    def testStringAsListOfOne( self ):
+        self.p4.connect()
+        client = self.p4.fetch_client()
+        altRoots = [ "/tmp/foo", "/tmp/bar" ]
+        client._altroots = altRoots
+        self.p4.save_client(client)
+        
+        client = self.p4.fetch_client()
+        self.assertEqual(client._altroots, altRoots, "AltRoots are not identical for list of two")
+        
+        altRoots = "/tmp/foo"
+        client._altroots = altRoots
+        self.p4.save_client(client)
+        
+        client = self.p4.fetch_client()
+        self.assertEqual(client._altRoots, [ altRoots ], "AltRoots are not identical for string")
+        
+        altRoots = ""
+        client._altroots = altRoots
+        self.p4.save_client(client)
+        
+        client = self.p4.fetch_client()
+        self.assertEqual( ("AltRoots" not in client), True , "AltRoots have not been deleted")
+    
+    def run_saved_context(self):
+        with self.p4.saved_context(cwd='/tmp'):
+            self.p4.run_files('...') # must fail
+    
+    def run_files(self):
+        self.p4.run_files('...', cwd='/tmp')
+    
+    def testContextHandlers( self ):
+        self.p4.connect()
+        cwd = self.p4.cwd
+        self.assertRaises(P4Exception, self.run_saved_context)            
+        self.assertEqual(self.p4.cwd, cwd, "Context not successfully restored in with statement")
+        
+        self.assertRaises(P4Exception, self.run_files)
+            
+        
+        self.assertEqual(self.p4.cwd, cwd, "Context not successfully restored in run method")
+    
 if __name__ == '__main__':
     unittest.main()
 
